/* 
 * Mach Operating System
 * Copyright (c) 1991,1990 Carnegie Mellon University
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 * 
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Carnegie Mellon requests users of this software to return to
 * 
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 * 
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */
/* 
 * HISTORY
 * $Log:	vm_param.h,v $
 * Revision 2.6  93/01/14  17:42:55  danner
 * 	Cleanup.
 * 	[92/06/10            pds]
 * 
 * Revision 2.5  91/12/10  16:32:48  jsb
 * 	Fixes from Intel
 * 	[91/12/10  15:33:46  jsb]
 * 
 * Revision 2.4  91/05/14  16:53:49  mrt
 * 	Correcting copyright
 * 
 * Revision 2.3  91/02/05  17:32:59  mrt
 * 	Changed to new Mach copyright
 * 	[91/02/01  17:11:44  mrt]
 * 
 * Revision 2.2  90/12/04  14:51:19  jsb
 * 	First checkin.
 * 	[90/12/03  22:05:31  jsb]
 * 
 */
/*
 * Machine dependent virtual memory parameters for i860.
 * Derived from i386 version.
 */

#ifndef	_MACH_I860_VM_PARAM_H_
#define _MACH_I860_VM_PARAM_H_

#define BYTE_SIZE	8	/* byte size in bits */

#define I860_PGBYTES	4096	/* bytes per 80860 page */
#define I860_PGSHIFT	12	/* number of bits to shift for pages */

/*
 *	Convert bytes to pages and convert pages to bytes.
 *	No rounding is used.
 */

#define i860_btop(x)		(((unsigned)(x)) >> I860_PGSHIFT)
#define i860_ptob(x)		(((unsigned)(x)) << I860_PGSHIFT)

/*
 *	Round off or truncate to the nearest page.  These will work
 *	for either addresses or counts.  (i.e. 1 byte rounds to 1 page
 *	bytes.
 */

#define i860_round_page(x)	((((unsigned)(x)) + I860_PGBYTES - 1) & \
					~(I860_PGBYTES-1))
#define i860_trunc_page(x)	(((unsigned)(x)) & ~(I860_PGBYTES-1))

#define VM_MIN_ADDRESS		((vm_offset_t) 0)
#define VM_MAX_ADDRESS		((vm_offset_t) 0xf8000000)

#define VM_MIN_TEXT_ADDRESS     ((vm_offset_t) 0xf8000000)

#define VM_MIN_KERNEL_ADDRESS	((vm_offset_t) 0xf8000000)
#define VM_MAX_KERNEL_ADDRESS	((vm_offset_t) 0xffffffff)

#define KERNEL_STACK_SIZE	(8*I860_PGBYTES)
#define INTSTACK_SIZE		(1*I860_PGBYTES)
						/* interrupt stack size */

/*
 *	Conversion between 80860 pages and VM pages
 */

#define trunc_i860_to_vm(p)	(atop(trunc_page(i860_ptob(p))))
#define round_i860_to_vm(p)	(atop(round_page(i860_ptob(p))))
#define vm_to_i860(p)		(i860_btop(ptoa(p)))

/*
 *	Physical memory is mapped 1-1 with virtual memory starting
 *	at VM_MIN_KERNEL_ADDRESS.
 */
#define phystokv(a) ((vm_offset_t)(a))

#endif	/* _MACH_I860_VM_PARAM_H_ */
